﻿Imports System.Data.Services.Client

Namespace Helpers.Zillow

    Public Class HomeValuationApiContainer
        Inherits DataServiceContext

        Public Sub New(ByVal serviceRoot As Uri)
            MyBase.New(serviceRoot)
        End Sub

        Public Property City As String
        Public Property ComparablesLink As String
        Public Property GraphsAndDataLink As String
        Public Property HomeDetailsLink As String
        Public Property Latitude As Double?
        Public Property LocalRealEstateForSaleByOwnerLink As String
        Public Property LocalRealEstateForSaleLink As String
        Public Property LocalRealEstateName As String
        Public Property LocalRealEstateOverviewLink As String
        Public Property LocalRealEstateRegionId As Integer?
        Public Property LocalRealEstateType As String
        Public Property LocalRealEstateZindexOneYearChange As Double?
        Public Property LocalRealEstateZindexValue As Double?
        Public Property Longitude As Double?
        Public Property MapThisHomeLink As String
        Public Property MyEstimatorLink As String
        Public Property MyZestimatorLink As String
        Public Property RegionsCityId As Integer?
        Public Property RegionsCountyId As Integer?
        Public Property RegionsStateId As Integer?
        Public Property RegionsZipCodeId As Integer?
        Public Property State As String
        Public Property Street As String
        Public Property ZestimateAmount As Double?
        Public Property ZestimateAmountCurrency As String
        Public Property ZestimateLastUpdated As String
        Public Property ZestimateOneWeekChange As Double?
        Public Property ZestimateOneWeekChangeDeprecated As Boolean?
        Public Property ZestimatePercentile As Double?
        Public Property ZestimateValuationRangeHigh As Double?
        Public Property ZestimateValuationRangeHighCurrency As String
        Public Property ZestimateValuationRangeLow As Double?
        Public Property ZestimateValuationRangeLowCurrency As String
        Public Property ZestimateValueChange As Double?
        Public Property ZestimateValueChangeCurrency As String
        Public Property ZestimateValueChangeDuration As Integer?
        Public Property ZillowPropertyId As Integer
        Public Property ZipCode As String


        Public Function GetChart(ByVal ZillowPropertyID As Integer, ByVal UnitType As String, ByVal Width As Integer?, ByVal Height As Integer?, ByVal ChartDuration As String) As DataServiceQuery(Of ChartsEntity)
            If (UnitType Is Nothing) Then
                Throw New ArgumentNullException("UnitType", "UnitType value cannot be null")
            End If
            Dim query As DataServiceQuery(Of ChartsEntity) = MyBase.CreateQuery(Of ChartsEntity)("GetChart").AddQueryOption("ZillowPropertyID", ZillowPropertyID)
            If (Not UnitType Is Nothing) Then
                query = query.AddQueryOption("UnitType", ("'" & Uri.EscapeDataString(UnitType) & "'"))
            End If
            If (Width.HasValue AndAlso Width.HasValue) Then
                query = query.AddQueryOption("Width", Width.Value)
            End If
            If (Height.HasValue AndAlso Height.HasValue) Then
                query = query.AddQueryOption("Height", Height.Value)
            End If
            If (Not ChartDuration Is Nothing) Then
                query = query.AddQueryOption("ChartDuration", ("'" & Uri.EscapeDataString(ChartDuration) & "'"))
            End If
            Return query
        End Function

        Public Function GetComparables(ByVal ZillowPropertyID As Integer, ByVal ComparablesCount As Integer) As DataServiceQuery(Of ComparablesEntity)
            Return MyBase.CreateQuery(Of ComparablesEntity)("GetComparables").AddQueryOption("ZillowPropertyID", ZillowPropertyID).AddQueryOption("ComparablesCount", ComparablesCount)
        End Function

        Public Function GetSearchResults(ByVal Address As String, ByVal CityStateAndZipCode As String) As DataServiceQuery(Of SearchResultsEntity)
            If (Address Is Nothing) Then
                Throw New ArgumentNullException("Address", "Address value cannot be null")
            End If
            If (CityStateAndZipCode Is Nothing) Then
                Throw New ArgumentNullException("CityStateAndZipCode", "CityStateAndZipCode value cannot be null")
            End If
            Dim query As DataServiceQuery(Of SearchResultsEntity) = MyBase.CreateQuery(Of SearchResultsEntity)("GetSearchResults")
            If (Not Address Is Nothing) Then
                query = query.AddQueryOption("Address", ("'" & Uri.EscapeDataString(Address) & "'"))
            End If
            If (Not CityStateAndZipCode Is Nothing) Then
                query = query.AddQueryOption("CityStateAndZipCode", ("'" & Uri.EscapeDataString(CityStateAndZipCode) & "'"))
            End If
            Return query
        End Function

        Public Function GetZestimate(ByVal ZillowPropertyID As Integer) As DataServiceQuery(Of ZestimateEntity)
            Return MyBase.CreateQuery(Of ZestimateEntity)("GetZestimate").AddQueryOption("ZillowPropertyID", ZillowPropertyID)
        End Function
    End Class

End Namespace
