﻿Imports System.Data.Services.Client

Namespace Helpers.ZilloW
    Public Class NeighborhoodDataApiContainer
        Inherits DataServiceContext
        Public Sub New(ByVal serviceRoot As Uri)
            MyBase.New(serviceRoot)
        End Sub

        Public Function GetDemographics(ByVal RegionId As Integer?, ByVal City As String, ByVal State As String, ByVal Neighborhood As String, ByVal ZipCode As String) As DataServiceQuery(Of DemographicsEntity)
            Dim query As DataServiceQuery(Of DemographicsEntity) = MyBase.CreateQuery(Of DemographicsEntity)("GetDemographics")
            If (RegionId.HasValue AndAlso RegionId.HasValue) Then
                query = query.AddQueryOption("RegionId", RegionId.Value)
            End If
            If (Not City Is Nothing) Then
                query = query.AddQueryOption("City", ("'" & Uri.EscapeDataString(City) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not Neighborhood Is Nothing) Then
                query = query.AddQueryOption("Neighborhood", ("'" & Uri.EscapeDataString(Neighborhood) & "'"))
            End If
            If (Not ZipCode Is Nothing) Then
                query = query.AddQueryOption("ZipCode", ("'" & Uri.EscapeDataString(ZipCode) & "'"))
            End If
            Return query
        End Function

        Public Function GetDemographicsByCity(ByVal City As String, ByVal State As String, ByVal Neighborhood As String) As DataServiceQuery(Of DemographicsEntity)
            If (City Is Nothing) Then
                Throw New ArgumentNullException("City", "City value cannot be null")
            End If
            If (State Is Nothing) Then
                Throw New ArgumentNullException("State", "State value cannot be null")
            End If
            Dim query As DataServiceQuery(Of DemographicsEntity) = MyBase.CreateQuery(Of DemographicsEntity)("GetDemographicsByCity")
            If (Not City Is Nothing) Then
                query = query.AddQueryOption("City", ("'" & Uri.EscapeDataString(City) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not Neighborhood Is Nothing) Then
                query = query.AddQueryOption("Neighborhood", ("'" & Uri.EscapeDataString(Neighborhood) & "'"))
            End If
            Return query
        End Function

        Public Function GetDemographicsByRegionId(ByVal RegionId As Integer) As DataServiceQuery(Of DemographicsEntity)
            Return MyBase.CreateQuery(Of DemographicsEntity)("GetDemographicsByRegionId").AddQueryOption("RegionId", RegionId)
        End Function

        Public Function GetDemographicsByZipCode(ByVal ZipCode As String) As DataServiceQuery(Of DemographicsEntity)
            If (ZipCode Is Nothing) Then
                Throw New ArgumentNullException("ZipCode", "ZipCode value cannot be null")
            End If
            Dim query As DataServiceQuery(Of DemographicsEntity) = MyBase.CreateQuery(Of DemographicsEntity)("GetDemographicsByZipCode")
            If (Not ZipCode Is Nothing) Then
                query = query.AddQueryOption("ZipCode", ("'" & Uri.EscapeDataString(ZipCode) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChart(ByVal UnitType As String, ByVal City As String, ByVal State As String, ByVal Neighborhood As String, ByVal ZipCode As String, ByVal Width As Integer?, ByVal Height As Integer?, ByVal ChartDuration As String) As DataServiceQuery(Of RegionChartEntity)
            If (UnitType Is Nothing) Then
                Throw New ArgumentNullException("UnitType", "UnitType value cannot be null")
            End If
            Dim query As DataServiceQuery(Of RegionChartEntity) = MyBase.CreateQuery(Of RegionChartEntity)("GetRegionChart")
            If (Not UnitType Is Nothing) Then
                query = query.AddQueryOption("UnitType", ("'" & Uri.EscapeDataString(UnitType) & "'"))
            End If
            If (Not City Is Nothing) Then
                query = query.AddQueryOption("City", ("'" & Uri.EscapeDataString(City) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not Neighborhood Is Nothing) Then
                query = query.AddQueryOption("Neighborhood", ("'" & Uri.EscapeDataString(Neighborhood) & "'"))
            End If
            If (Not ZipCode Is Nothing) Then
                query = query.AddQueryOption("ZipCode", ("'" & Uri.EscapeDataString(ZipCode) & "'"))
            End If
            If (Width.HasValue AndAlso Width.HasValue) Then
                query = query.AddQueryOption("Width", Width.Value)
            End If
            If (Height.HasValue AndAlso Height.HasValue) Then
                query = query.AddQueryOption("Height", Height.Value)
            End If
            If (Not ChartDuration Is Nothing) Then
                query = query.AddQueryOption("ChartDuration", ("'" & Uri.EscapeDataString(ChartDuration) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChartByCity(ByVal UnitType As String, ByVal City As String, ByVal State As String, ByVal Neighborhood As String, ByVal Width As Integer?, ByVal Height As Integer?, ByVal ChartDuration As String) As DataServiceQuery(Of RegionChartEntity)
            If (UnitType Is Nothing) Then
                Throw New ArgumentNullException("UnitType", "UnitType value cannot be null")
            End If
            If (City Is Nothing) Then
                Throw New ArgumentNullException("City", "City value cannot be null")
            End If
            If (State Is Nothing) Then
                Throw New ArgumentNullException("State", "State value cannot be null")
            End If
            Dim query As DataServiceQuery(Of RegionChartEntity) = MyBase.CreateQuery(Of RegionChartEntity)("GetRegionChartByCity")
            If (Not UnitType Is Nothing) Then
                query = query.AddQueryOption("UnitType", ("'" & Uri.EscapeDataString(UnitType) & "'"))
            End If
            If (Not City Is Nothing) Then
                query = query.AddQueryOption("City", ("'" & Uri.EscapeDataString(City) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not Neighborhood Is Nothing) Then
                query = query.AddQueryOption("Neighborhood", ("'" & Uri.EscapeDataString(Neighborhood) & "'"))
            End If
            If (Width.HasValue AndAlso Width.HasValue) Then
                query = query.AddQueryOption("Width", Width.Value)
            End If
            If (Height.HasValue AndAlso Height.HasValue) Then
                query = query.AddQueryOption("Height", Height.Value)
            End If
            If (Not ChartDuration Is Nothing) Then
                query = query.AddQueryOption("ChartDuration", ("'" & Uri.EscapeDataString(ChartDuration) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChartByState(ByVal UnitType As String, ByVal State As String, ByVal Width As Integer?, ByVal Height As Integer?, ByVal ChartDuration As String) As DataServiceQuery(Of RegionChartEntity)
            If (UnitType Is Nothing) Then
                Throw New ArgumentNullException("UnitType", "UnitType value cannot be null")
            End If
            If (State Is Nothing) Then
                Throw New ArgumentNullException("State", "State value cannot be null")
            End If
            Dim regionQuery As DataServiceQuery(Of RegionChartEntity) = MyBase.CreateQuery(Of RegionChartEntity)("GetRegionChartByState")
            If (Not UnitType Is Nothing) Then
                regionQuery = regionQuery.AddQueryOption("UnitType", ("'" & Uri.EscapeDataString(UnitType) & "'"))
            End If
            If (Not State Is Nothing) Then
                regionQuery = regionQuery.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Width.HasValue AndAlso Width.HasValue) Then
                regionQuery = regionQuery.AddQueryOption("Width", Width.Value)
            End If
            If (Height.HasValue AndAlso Height.HasValue) Then
                regionQuery = regionQuery.AddQueryOption("Height", Height.Value)
            End If
            If (Not ChartDuration Is Nothing) Then
                regionQuery = regionQuery.AddQueryOption("ChartDuration", ("'" & Uri.EscapeDataString(ChartDuration) & "'"))
            End If
            Return regionQuery
        End Function

        Public Function GetRegionChartByZipCode(ByVal UnitType As String, ByVal ZipCode As String, ByVal Neighborhood As String, ByVal Width As Integer?, ByVal Height As Integer?, ByVal ChartDuration As String) As DataServiceQuery(Of RegionChartEntity)
            If (UnitType Is Nothing) Then
                Throw New ArgumentNullException("UnitType", "UnitType value cannot be null")
            End If
            If (ZipCode Is Nothing) Then
                Throw New ArgumentNullException("ZipCode", "ZipCode value cannot be null")
            End If
            Dim query As DataServiceQuery(Of RegionChartEntity) = MyBase.CreateQuery(Of RegionChartEntity)("GetRegionChartByZipCode")
            If (Not UnitType Is Nothing) Then
                query = query.AddQueryOption("UnitType", ("'" & Uri.EscapeDataString(UnitType) & "'"))
            End If
            If (Not ZipCode Is Nothing) Then
                query = query.AddQueryOption("ZipCode", ("'" & Uri.EscapeDataString(ZipCode) & "'"))
            End If
            If (Not Neighborhood Is Nothing) Then
                query = query.AddQueryOption("Neighborhood", ("'" & Uri.EscapeDataString(Neighborhood) & "'"))
            End If
            If (Width.HasValue AndAlso Width.HasValue) Then
                query = query.AddQueryOption("Width", Width.Value)
            End If
            If (Height.HasValue AndAlso Height.HasValue) Then
                query = query.AddQueryOption("Height", Height.Value)
            End If
            If (Not ChartDuration Is Nothing) Then
                query = query.AddQueryOption("ChartDuration", ("'" & Uri.EscapeDataString(ChartDuration) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChartUS(ByVal UnitType As String, ByVal Width As Integer?, ByVal Height As Integer?, ByVal ChartDuration As String) As DataServiceQuery(Of RegionChartEntity)
            If (UnitType Is Nothing) Then
                Throw New ArgumentNullException("UnitType", "UnitType value cannot be null")
            End If
            Dim footnotes As DataServiceQuery(Of RegionChartEntity) = MyBase.CreateQuery(Of RegionChartEntity)("GetRegionChartUS")
            If (Not UnitType Is Nothing) Then
                footnotes = footnotes.AddQueryOption("UnitType", ("'" & Uri.EscapeDataString(UnitType) & "'"))
            End If
            If (Width.HasValue AndAlso Width.HasValue) Then
                footnotes = footnotes.AddQueryOption("Width", Width.Value)
            End If
            If (Height.HasValue AndAlso Height.HasValue) Then
                footnotes = footnotes.AddQueryOption("Height", Height.Value)
            End If
            If (Not ChartDuration Is Nothing) Then
                footnotes = footnotes.AddQueryOption("ChartDuration", ("'" & Uri.EscapeDataString(ChartDuration) & "'"))
            End If
            Return footnotes
        End Function

        Public Function GetRegionChildren(ByVal RegionId As Integer?, ByVal Country As String, ByVal City As String, ByVal County As String, ByVal State As String, ByVal ChildType As String) As DataServiceQuery(Of RegionChildrenEntity)
            Dim query As DataServiceQuery(Of RegionChildrenEntity) = MyBase.CreateQuery(Of RegionChildrenEntity)("GetRegionChildren")
            If (RegionId.HasValue AndAlso RegionId.HasValue) Then
                query = query.AddQueryOption("RegionId", RegionId.Value)
            End If
            If (Not Country Is Nothing) Then
                query = query.AddQueryOption("Country", ("'" & Uri.EscapeDataString(Country) & "'"))
            End If
            If (Not City Is Nothing) Then
                query = query.AddQueryOption("City", ("'" & Uri.EscapeDataString(City) & "'"))
            End If
            If (Not County Is Nothing) Then
                query = query.AddQueryOption("County", ("'" & Uri.EscapeDataString(County) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not ChildType Is Nothing) Then
                query = query.AddQueryOption("ChildType", ("'" & Uri.EscapeDataString(ChildType) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChildrenByCity(ByVal City As String, ByVal State As String, ByVal ChildType As String) As DataServiceQuery(Of RegionChildrenEntity)
            If (City Is Nothing) Then
                Throw New ArgumentNullException("City", "City value cannot be null")
            End If
            If (State Is Nothing) Then
                Throw New ArgumentNullException("State", "State value cannot be null")
            End If
            Dim query As DataServiceQuery(Of RegionChildrenEntity) = MyBase.CreateQuery(Of RegionChildrenEntity)("GetRegionChildrenByCity")
            If (Not City Is Nothing) Then
                query = query.AddQueryOption("City", ("'" & Uri.EscapeDataString(City) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not ChildType Is Nothing) Then
                query = query.AddQueryOption("ChildType", ("'" & Uri.EscapeDataString(ChildType) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChildrenByCounty(ByVal County As String, ByVal State As String, ByVal ChildType As String) As DataServiceQuery(Of RegionChildrenEntity)
            If (County Is Nothing) Then
                Throw New ArgumentNullException("County", "County value cannot be null")
            End If
            If (State Is Nothing) Then
                Throw New ArgumentNullException("State", "State value cannot be null")
            End If
            Dim query As DataServiceQuery(Of RegionChildrenEntity) = MyBase.CreateQuery(Of RegionChildrenEntity)("GetRegionChildrenByCounty")
            If (Not County Is Nothing) Then
                query = query.AddQueryOption("County", ("'" & Uri.EscapeDataString(County) & "'"))
            End If
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not ChildType Is Nothing) Then
                query = query.AddQueryOption("ChildType", ("'" & Uri.EscapeDataString(ChildType) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChildrenByRegionId(ByVal RegionId As Integer, ByVal ChildType As String) As DataServiceQuery(Of RegionChildrenEntity)
            Dim query As DataServiceQuery(Of RegionChildrenEntity) = MyBase.CreateQuery(Of RegionChildrenEntity)("GetRegionChildrenByRegionId").AddQueryOption("RegionId", RegionId)
            If (Not ChildType Is Nothing) Then
                query = query.AddQueryOption("ChildType", ("'" & Uri.EscapeDataString(ChildType) & "'"))
            End If
            Return query
        End Function

        Public Function GetRegionChildrenByState(ByVal State As String, ByVal ChildType As String) As DataServiceQuery(Of RegionChildrenEntity)
            If (State Is Nothing) Then
                Throw New ArgumentNullException("State", "State value cannot be null")
            End If
            Dim query As DataServiceQuery(Of RegionChildrenEntity) = MyBase.CreateQuery(Of RegionChildrenEntity)("GetRegionChildrenByState")
            If (Not State Is Nothing) Then
                query = query.AddQueryOption("State", ("'" & Uri.EscapeDataString(State) & "'"))
            End If
            If (Not ChildType Is Nothing) Then
                query = query.AddQueryOption("ChildType", ("'" & Uri.EscapeDataString(ChildType) & "'"))
            End If
            Return query
        End Function

    End Class

    Public Class DemographicsEntity
        Public Sub New()
        End Sub
        Public Property AffordabilityLink As String
        Public Property ChartName As String
        Public Property ChartUrl As String
        Public Property City As String
        Public Property ForeclosuresLink As String
        Public Property ForSaleByOwnerLink As String
        Public Property ForSaleLink As String
        Public Property HomesAndRealEstateLink As String
        Public Property Latitude As Double?
        Public Property Longitude As Double?
        Public Property MainLink As String
        Public Property Market As String
        Public Property MarketDeprecated As Boolean?
        Public Property Neighborhood As String
        Public Property PeopleLink As String
        Public Property RecentlySoldLink As String
        Public Property RegionId As Integer?
        Public Property State As String
    End Class

    Public Class RegionChartEntity
        Public Sub New()
        End Sub
        Public Property ForSaleByOwnerLink As String
        Public Property ForSaleLink As String
        Public Property Url As String
        Public Property Zindex As Integer?
        Public Property ZindexCurrency As String
    End Class

    Public Class RegionChildrenEntity
        Public Sub New()
        End Sub
        Public Property Latitude As String
        Public Property Longitude As String
        Public Property Name As String
        Public Property ParentRegionCity As String
        Public Property ParentRegionCityUrl As String
        Public Property ParentRegionCountry As String
        Public Property ParentRegionCounty As String
        Public Property ParentRegionId As Integer
        Public Property ParentRegionLatitude As Double?
        Public Property ParentRegionLongitude As Double?
        Public Property ParentRegionState As String
        Public Property RegionId As Integer
        Public Property RegionPageUrl As String
        Public Property SubRegionType As String
        Public Property Zindex As Integer?
    End Class
End Namespace
