﻿Imports System.Data.Services.Client

Namespace Helpers.Zillow
    Public Class PropertyDetailsApiContainer
        Inherits DataServiceContext
        ' Methods
        Public Sub New(ByVal serviceRoot As Uri)
            MyBase.New(serviceRoot)
        End Sub

        Public Function GetDeepComparables(ByVal ZillowPropertyID As Integer, ByVal ComparablesCount As Integer) As DataServiceQuery(Of DeepComparablesEntity)
            Return MyBase.CreateQuery(Of DeepComparablesEntity)("GetDeepComparables").AddQueryOption("ZillowPropertyID", ZillowPropertyID).AddQueryOption("ComparablesCount", ComparablesCount)
        End Function

        Public Function GetDeepSearchResults(ByVal Address As String, ByVal CityStateAndZipCode As String) As DataServiceQuery(Of DeepSearchResultsEntity)
            If (Address Is Nothing) Then
                Throw New ArgumentNullException("Address", "Address value cannot be null")
            End If
            If (CityStateAndZipCode Is Nothing) Then
                Throw New ArgumentNullException("CityStateAndZipCode", "CityStateAndZipCode value cannot be null")
            End If
            Dim query As DataServiceQuery(Of DeepSearchResultsEntity) = MyBase.CreateQuery(Of DeepSearchResultsEntity)("GetDeepSearchResults")
            If (Not Address Is Nothing) Then
                query = query.AddQueryOption("Address", ("'" & Uri.EscapeDataString(Address) & "'"))
            End If
            If (Not CityStateAndZipCode Is Nothing) Then
                query = query.AddQueryOption("CityStateAndZipCode", ("'" & Uri.EscapeDataString(CityStateAndZipCode) & "'"))
            End If
            Return query
        End Function

        Public Function GetUpdatedPropertyDetails(ByVal ZillowPropertyID As Integer) As DataServiceQuery(Of UpdatedPropertyDetailsEntity)
            Return MyBase.CreateQuery(Of UpdatedPropertyDetailsEntity)("GetUpdatedPropertyDetails").AddQueryOption("ZillowPropertyID", ZillowPropertyID)
        End Function

    End Class

    Public Class DeepComparablesEntity
        Public Sub New()
        End Sub
        Public Property Bathrooms As Double?
        Public Property Bedrooms As Double?
        Public Property City As String
        Public Property ComparablesLink As String
        Public Property FinishedSqFt As Double?
        Public Property GraphsAndDataLink As String
        Public Property HomeDetailsLink As String
        Public Property LastSoldDate As String
        Public Property LastSoldPrice As Double?
        Public Property LastSoldPriceCurrency As String
        Public Property Latitude As Double?
        Public Property LocalRealEstateCityForSaleByOwnerLink As String
        Public Property LocalRealEstateCityForSaleLink As String
        Public Property LocalRealEstateCityName As String
        Public Property LocalRealEstateCityOverviewLink As String
        Public Property LocalRealEstateCityRegionId As Integer?
        Public Property LocalRealEstateCityZindexOneYearChange As Double?
        Public Property LocalRealEstateCityZindexValue As Integer?
        Public Property LocalRealEstateNeighborhoodForSaleByOwnerLink As String
        Public Property LocalRealEstateNeighborhoodForSaleLink As String
        Public Property LocalRealEstateNeighborhoodName As String
        Public Property LocalRealEstateNeighborhoodOverviewLink As String
        Public Property LocalRealEstateNeighborhoodRegionId As Integer?
        Public Property LocalRealEstateNeighborhoodZindexOneYearChange As Double?
        Public Property LocalRealEstateNeighborhoodZindexValue As Integer?
        Public Property LocalRealEstateStateForSaleByOwnerLink As String
        Public Property LocalRealEstateStateForSaleLink As String
        Public Property LocalRealEstateStateName As String
        Public Property LocalRealEstateStateOverviewLink As String
        Public Property LocalRealEstateStateRegionId As Integer?
        Public Property LocalRealEstateStateZindexOneYearChange As Double?
        Public Property LocalRealEstateStateZindexValue As Integer?
        Public Property Longitude As Double?
        Public Property LotSizeSqFt As Double?
        Public Property MapThisHomeLink As String
        Public Property MyEstimatorLink As String
        Public Property MyZestimatorLink As String
        Public Property PrincipalBathrooms As Double?
        Public Property PrincipalBedrooms As Double?
        Public Property PrincipalCity As String
        Public Property PrincipalComparablesLink As String
        Public Property PrincipalFinishedSqFt As Double?
        Public Property PrincipalGraphsAndDataLink As String
        Public Property PrincipalHomeDetailsLink As String
        Public Property PrincipalLastSoldDate As String
        Public Property PrincipalLastSoldPrice As Double?
        Public Property PrincipalLastSoldPriceCurrency As String
        Public Property PrincipalLatitude As Double?
        Public Property PrincipalLongitude As Double?
        Public Property PrincipalLotSizeSqFt As Double?
        Public Property PrincipalMapThisHomeLink As String
        Public Property PrincipalMyEstimatorLink As String
        Public Property PrincipalMyZestimatorLink As String
        Public Property PrincipalState As String
        Public Property PrincipalStreet As String
        Public Property PrincipalTaxAssessment As Double?
        Public Property PrincipalTaxAssessmentYear As Short?
        Public Property PrincipalYearBuilt As Integer?
        Public Property PrincipalZestimateAmount As Double?
        Public Property PrincipalZestimateAmountCurrency As String
        Public Property PrincipalZestimateLastUpdated As String
        Public Property PrincipalZestimateOneWeekChange As Double?
        Public Property PrincipalZestimateOneWeekChangeDeprecated As Boolean?
        Public Property PrincipalZestimatePercentile As Double?
        Public Property PrincipalZestimateValuationRangeHigh As Double?
        Public Property PrincipalZestimateValuationRangeHighCurrency As String
        Public Property PrincipalZestimateValuationRangeLow As Double?
        Public Property PrincipalZestimateValuationRangeLowCurrency As String
        Public Property PrincipalZestimateValueChange As Double?
        Public Property PrincipalZestimateValueChangeCurrency As String
        Public Property PrincipalZestimateValueChangeDuration As Integer?
        Public Property PrincipalZillowPropertyId As Integer
        Public Property PrincipalZipCode As String
        Public Property Score As Double
        Public Property State As String
        Public Property Street As String
        Public Property TaxAssessment As Double?
        Public Property TaxAssessmentYear As Short?
        Public Property YearBuilt As Integer?
        Public Property ZestimateAmount As Double?
        Public Property ZestimateAmountCurrency As String
        Public Property ZestimateLastUpdated As String
        Public Property ZestimateOneWeekChange As Double?
        Public Property ZestimateOneWeekChangeDeprecated As Boolean?
        Public Property ZestimatePercentile As Double?
        Public Property ZestimateValuationRangeHigh As Double?
        Public Property ZestimateValuationRangeHighCurrency As String
        Public Property ZestimateValuationRangeLow As Double?
        Public Property ZestimateValuationRangeLowCurrency As String
        Public Property ZestimateValueChange As Double?
        Public Property ZestimateValueChangeCurrency As String
        Public Property ZestimateValueChangeDuration As Integer?
        Public Property ZillowPropertyId As Integer
        Public Property ZipCode As String
    End Class

    Public Class UpdatedPropertyDetailsEntity
        Public Sub New()
        End Sub
        Public Property City As String
        Public Property CurrentMonthPageViewCount As Integer?
        Public Property EditedFactsAppliances As String
        Public Property EditedFactsBasement As String
        Public Property EditedFactsBathrooms As Double?
        Public Property EditedFactsBedrooms As Double?
        Public Property EditedFactsFinishedSqFt As Double?
        Public Property EditedFactsFloorCovering As String
        Public Property EditedFactsHeatingSources As String
        Public Property EditedFactsHeatingSystem As String
        Public Property EditedFactsLotSizeSqFt As Double?
        Public Property EditedFactsNumberOfFloors As Integer?
        Public Property EditedFactsParkingType As String
        Public Property EditedFactsRoof As String
        Public Property EditedFactsRooms As String
        Public Property EditedFactsUseCode As String
        Public Property EditedFactsView As String
        Public Property EditedFactsYearBuilt As Integer?
        Public Property EditedFactsYearUpdated As Integer?
        Public Property ElementarySchool As String
        Public Property HomeDescription As String
        Public Property HomeDetailsLink As String
        Public Property HomeInfoLink As String
        Public Property ImagesCount As Short?
        Public Property ImageUrl As String
        Public Property Latitude As Double?
        Public Property Longitude As Double?
        Public Property MiddleSchool As String
        Public Property Neighborhood As String
        Public Property PhotoGalleryLink As String
        Public Property PostingAgentbrokerage As String
        Public Property PostingAgentName As String
        Public Property PostingagentProfileUrl As String
        Public Property PostingExternalUrl As String
        Public Property PostingLastUpdatedDate As DateTime?
        Public Property PostingMls As String
        Public Property PostingStatus As String
        Public Property PostingType As String
        Public Property Price As Double?
        Public Property PriceCurrency As Double?
        Public Property SchoolDistrict As String
        Public Property State As String
        Public Property Street As String
        Public Property TotalMonthPageViewCount As Integer?
        Public Property ZillowPropertyId As Integer
        Public Property ZipCode As String
    End Class
End Namespace